@@ -393,21 +393,26 @@ def error_dialog(parent, title, msg, det_msg='', show=False,
 
 
 def question_dialog(parent, title, msg, det_msg='', show_copy_button=False,
-        default_yes=True,
-        # Skippable dialogs
-        # Set skip_dialog_name to a unique name for this dialog
-        # Set skip_dialog_msg to a message displayed to the user
-        skip_dialog_name=None, skip_dialog_msg=_('Show this confirmation again'),
-        skip_dialog_skipped_value=True, skip_dialog_skip_precheck=True,
-        # Override icon (QIcon to be used as the icon for this dialog or string for I())
-        override_icon=None,
-        # Change the text/icons of the yes and no buttons.
-        # The icons must be QIcon objects or strings for I()
-        yes_text=None, no_text=None, yes_icon=None, no_icon=None,
-    ):
+    default_yes=True,
+    # Skippable dialogs
+    # Set skip_dialog_name to a unique name for this dialog
+    # Set skip_dialog_msg to a message displayed to the user
+    skip_dialog_name=None, skip_dialog_msg=_('Show this confirmation again'),
+    skip_dialog_skipped_value=True, skip_dialog_skip_precheck=True,
+    # Override icon (QIcon to be used as the icon for this dialog or string for I())
+    override_icon=None,
+    # Change the text/icons of the yes and no buttons.
+    # The icons must be QIcon objects or strings for I()
+    yes_text=None, no_text=None, yes_icon=None, no_icon=None,
+):
     from calibre.gui2.dialogs.message_box import MessageBox
 
-    auto_skip = set(gprefs.get('questions_to_auto_skip', []))
+    if not isinstance(skip_dialog_name, unicode_type):
+        skip_dialog_name = None
+    try:
+        auto_skip = set(gprefs.get('questions_to_auto_skip', ()))
+    except Exception:
+        auto_skip = set()
     if (skip_dialog_name is not None and skip_dialog_name in auto_skip):
         return bool(skip_dialog_skipped_value)
 
