@@ -127,7 +127,7 @@ class IdLinksRuleEdit(Dialog):
         self.l = l = QFormLayout(self)
         l.setFieldGrowthPolicy(l.AllNonFixedFieldsGrow)
         l.addRow(QLabel(_(
-            'The key of the identifier, for example, in isbn:XXX, the key is isbn')))
+            'The key of the identifier, for example, in isbn:XXX, the key is ISBN')))
         self.key = k = QLineEdit(self)
         l.addRow(_('&Key:'), k)
         l.addRow(QLabel(_(
@@ -412,6 +412,7 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         r('row_numbers_in_book_list', gprefs)
         r('tag_browser_old_look', gprefs)
         r('tag_browser_hide_empty_categories', gprefs)
+        r('tag_browser_always_autocollapse', gprefs)
         r('tag_browser_show_tooltips', gprefs)
         r('bd_show_cover', gprefs)
         r('bd_overlay_cover_size', gprefs)
@@ -441,6 +442,8 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
             (_('Left'), 'left'), (_('Top'), 'top'), (_('Right'), 'right'), (_('Bottom'), 'bottom')])
         r('book_list_extra_row_spacing', gprefs)
         r('booklist_grid', gprefs)
+        r('book_details_comments_heading_pos', gprefs, choices=[
+            (_('Never'), 'hide'), (_('Above text'), 'above'), (_('Beside text'), 'side')])
         self.cover_browser_title_template_button.clicked.connect(self.edit_cb_title_template)
         self.id_links_button.clicked.connect(self.edit_id_link_rules)
 
